@@ -61,7 +61,7 @@ sub _prep_for_execute {
   }
   $new_sql .= join '', @sql_part;
 
-  return ($new_sql);
+  return ($new_sql, []);
 }
 
 =head1 AUTHORS
