@@ -1,7 +1,7 @@
 package # hide from PAUSE
     DBICTest::Schema::ForceForeign;
 
-use base 'DBIx::Class::Core';
+use base qw/DBICTest::BaseResult/;
 
 __PACKAGE__->table('forceforeign');
 __PACKAGE__->add_columns(
@@ -14,7 +14,7 @@ __PACKAGE__->set_primary_key(qw/artist/);
 # since it uses the PK
 __PACKAGE__->might_have(
 			'artist_1', 'DBICTest::Schema::Artist', {
-			    'foreign.artist_id' => 'self.artist',
+			    'foreign.artistid' => 'self.artist',
 			}, {
 			    is_foreign_key_constraint => 1,
 			},
@@ -29,4 +29,13 @@ __PACKAGE__->might_have(
 			},
 );
 
+# Normally this would appear as a FK constraint
+__PACKAGE__->belongs_to(
+			'cd_3', 'DBICTest::Schema::CD', {
+			    'foreign.cdid' => 'self.cd',
+			}, {
+			    is_foreign_key_constraint => 0,
+			},
+);
+
 1;
